@@ -4,11 +4,15 @@ import torch
 from cellseg_models_pytorch.decoders import Decoder
 
 
-@pytest.mark.parametrize("long_skip", ["unet", "unetpp", "unet3p", "unet3p-lite"])
+@pytest.mark.parametrize(
+    "long_skip", ["unet", "unetpp", "unet3p", "unet3p-lite", "cross-attn"]
+)
 @pytest.mark.parametrize("merge_policy", ["cat", "sum"])
-def test_decoder_fwdbwd(long_skip, merge_policy):
-    enc_channels = (64, 32, 16, 8, 8)
-    out_dims = [256 // 2**i for i in range(6)][::-1]
+@pytest.mark.parametrize("use_conv", [True, False])
+@pytest.mark.parametrize("use_tr", [True, False])
+def test_decoder_fwdbwd(long_skip, merge_policy, use_conv, use_tr):
+    enc_channels = (32, 32, 32, 32)
+    out_dims = [32 // 2**i for i in range(4)][::-1]
 
     decoder1_kwargs = {"merge_policy": merge_policy}
     decoder2_kwargs = {"merge_policy": merge_policy}
@@ -23,17 +27,30 @@ def test_decoder_fwdbwd(long_skip, merge_policy):
         decoder5_kwargs,
     )
 
+    n_layers = None
+    n_blocks = None
+    if use_conv:
+        n_layers = (1, 1, 1, 1)
+        n_blocks = ((2,), (2,), (2,), (2,))
+
+    n_tr_layers = None
+    n_tr_blocks = None
+    if use_tr:
+        n_tr_layers = (1, 1, 1, 1)
+        n_tr_blocks = ((1,), (1,), (1,), (1,))
+
     decoder = Decoder(
         enc_channels=enc_channels,
-        model_input_size=256,
-        out_channels=(64, 32, 16, 8, 8),
-        n_layers=(1, 1, 1, 1, 1),
-        n_blocks=((2,), (2,), (2,), (2,), (2,)),
+        out_channels=(32, 32, 32, 32),
+        n_conv_layers=n_layers,
+        n_conv_blocks=n_blocks,
+        n_transformers=n_tr_layers,
+        n_transformer_blocks=n_tr_blocks,
         long_skip=long_skip,
         stage_params=stage_params,
     )
 
-    x = [torch.rand([1, enc_channels[i], out_dims[i], out_dims[i]]) for i in range(5)]
+    x = [torch.rand([1, enc_channels[i], out_dims[i], out_dims[i]]) for i in range(4)]
     out = decoder(*x)
 
     out[-1].mean().backward()
